@@ -4,7 +4,7 @@
  * License: GPL v2
  * Copyright (c) 2000-2007 Ethan Galstad (nagios@nagios.org)
  *
- * Last Modified: 2021-10-27
+ * Last Modified: 2024-08-01
  *
  * Command line: SEND_NSCA <host_address> [-p port] [-to to_sec] [-c config_file]
  *
@@ -15,10 +15,12 @@
 
 /*#define DEBUG*/
 
+#define _GNU_SOURCE
 #include "../include/common.h"
 #include "../include/config.h"
 #include "../include/netutils.h"
 #include "../include/utils.h"
+#include <stdio.h>
 
 time_t start_time,end_time;
 
@@ -344,7 +346,10 @@ int main(int argc, char **argv){
 		printf("%d data packet(s) sent to host successfully.\n",total_packets);
 
 	/* exit cleanly */
-	do_exit(STATE_OK);
+	if (total_packets == 0)
+		do_exit(STATE_CRITICAL);
+	else
+		do_exit(STATE_OK);
 
 	/* no compiler complaints here... */
 	return STATE_OK;
